@@ -52,7 +52,7 @@ public:
         , webshortcutMenuManager(new KIO::KUriFilterSearchProviderActions(q))
     {
         KConfig sonnetKConfig(QStringLiteral("sonnetrc"));
-        KConfigGroup group(&sonnetKConfig, "Spelling");
+        KConfigGroup group(&sonnetKConfig, QLatin1String("Spelling"));
         checkSpellingEnabled = group.readEntry("checkerEnabledByDefault", false);
         supportFeatures |= PlainTextEditor::Search;
         supportFeatures |= PlainTextEditor::SpellChecking;
@@ -866,8 +866,8 @@ void PlainTextEditor::setSpellCheckingConfigFileName(const QString &_fileName)
 {
     d->spellCheckingConfigFileName = _fileName;
     KSharedConfig::Ptr config = KSharedConfig::openConfig(d->spellCheckingConfigFileName);
-    if (config->hasGroup("Spelling")) {
-        KConfigGroup group(config, "Spelling");
+    if (config->hasGroup(QLatin1String("Spelling"))) {
+        KConfigGroup group(config, QLatin1String("Spelling"));
         d->checkSpellingEnabled = group.readEntry("checkerEnabledByDefault", false);
         d->spellCheckingLanguage = group.readEntry("Language", QString());
     }
@@ -905,7 +905,7 @@ void PlainTextEditor::setSpellCheckingLanguage(const QString &_language)
     if (_language != d->spellCheckingLanguage) {
         d->spellCheckingLanguage = _language;
         KSharedConfig::Ptr config = KSharedConfig::openConfig(d->spellCheckingConfigFileName);
-        KConfigGroup group(config, "Spelling");
+        KConfigGroup group(config, QLatin1String("Spelling"));
         group.writeEntry("Language", d->spellCheckingLanguage);
         setCheckSpellingEnabled(checkSpellingEnabled());
 
@@ -917,7 +917,7 @@ void PlainTextEditor::slotToggleAutoSpellCheck()
 {
     setCheckSpellingEnabled(!checkSpellingEnabled());
     KSharedConfig::Ptr config = KSharedConfig::openConfig(d->spellCheckingConfigFileName);
-    KConfigGroup group(config, "Spelling");
+    KConfigGroup group(config, QLatin1String("Spelling"));
     group.writeEntry("checkerEnabledByDefault", d->checkSpellingEnabled);
 }
 
