@@ -8,7 +8,11 @@
 #include <KLocalizedString>
 #include <QFormLayout>
 #include <QLineEdit>
+#if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
 #include <TextAddonsWidgets/LineEditCatchReturnKey>
+#else
+#include <KLineEditEventHandler>
+#endif
 
 LingvaEngineWidget::LingvaEngineWidget(QWidget *parent)
     : QWidget{parent}
@@ -21,7 +25,11 @@ LingvaEngineWidget::LingvaEngineWidget(QWidget *parent)
     mServerUrl->setObjectName(QStringLiteral("mServerUrl"));
     mServerUrl->setClearButtonEnabled(true);
     mainLayout->addRow(i18n("Server Url:"), mServerUrl);
+#if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
     new TextAddonsWidgets::LineEditCatchReturnKey(mServerUrl, this);
+#else
+    KLineEditEventHandler::catchReturnKey(mServerUrl);
+#endif
 }
 
 LingvaEngineWidget::~LingvaEngineWidget() = default;
@@ -35,3 +43,5 @@ void LingvaEngineWidget::setServerUrl(const QString &serverUrl)
 {
     mServerUrl->setText(serverUrl);
 }
+
+#include "moc_lingvaenginewidget.cpp"
