@@ -38,6 +38,10 @@ TranslatorConfigureListsWidget::TranslatorConfigureListsWidget(QWidget *parent)
     auto mainLayout = new QVBoxLayout(this);
     mainLayout->setObjectName(QStringLiteral("mainLayout"));
     d->mEngineConfigureComboWidget->setObjectName(QStringLiteral("mEngineConfigureComboWidget"));
+    connect(d->mEngineConfigureComboWidget,
+            &TranslatorConfigureComboWidget::configureChanged,
+            this,
+            &TranslatorConfigureListsWidget::slotEngineSettingsChanged);
 
     auto hboxLayout = new QHBoxLayout;
     hboxLayout->setObjectName(QStringLiteral("hboxLayout"));
@@ -78,6 +82,11 @@ void TranslatorConfigureListsWidget::load()
     d->mEngineConfigureComboWidget->load();
 }
 
+void TranslatorConfigureListsWidget::slotEngineSettingsChanged(const QString &engineName)
+{
+    slotEngineChanged(engineName);
+}
+
 void TranslatorConfigureListsWidget::loadLanguagesList()
 {
     KConfigGroup groupTranslate(KSharedConfig::openConfig(), TranslatorUtil::groupTranslateName());
@@ -87,6 +96,25 @@ void TranslatorConfigureListsWidget::loadLanguagesList()
     d->mToLanguageWidget->setSelectedLanguages(toLanguages);
 }
 
+void TranslatorConfigureListsWidget::fillFromToLanguages(const QMap<TextTranslator::TranslatorUtil::Language, QString> &listFromLanguage,
+                                                         const QMap<TextTranslator::TranslatorUtil::Language, QString> &listToLanguage)
+{
+    QMapIterator<TranslatorUtil::Language, QString> i(listFromLanguage);
+    TranslatorUtil translatorUtil;
+    while (i.hasNext()) {
+        i.next();
+        const QString languageCode = TranslatorUtil::languageCode(i.key());
+        d->mFromLanguageWidget->addItem(i.value(), languageCode);
+    }
+
+    QMapIterator<TranslatorUtil::Language, QString> toLangIt(listToLanguage);
+    while (toLangIt.hasNext()) {
+        toLangIt.next();
+        const QString languageCode = TranslatorUtil::languageCode(toLangIt.key());
+        d->mToLanguageWidget->addItem(toLangIt.value(), languageCode);
+    }
+}
+
 void TranslatorConfigureListsWidget::fillLanguages(const QMap<TextTranslator::TranslatorUtil::Language, QString> &listLanguage)
 {
     QMapIterator<TranslatorUtil::Language, QString> i(listLanguage);
@@ -103,10 +131,12 @@ void TranslatorConfigureListsWidget::fillLanguages(const QMap<TextTranslator::Tr
 
 void TranslatorConfigureListsWidget::slotEngineChanged(const QString &engine)
 {
-    const QMap<TextTranslator::TranslatorUtil::Language, QString> listLanguage = TextTranslator::TranslatorEngineLoader::self()->supportedLanguages(engine);
+    const QMap<TextTranslator::TranslatorUtil::Language, QString> listFromLanguage =
+        TextTranslator::TranslatorEngineLoader::self()->supportedFromLanguages(engine);
+    const QMap<TextTranslator::TranslatorUtil::Language, QString> listToLanguage = TextTranslator::TranslatorEngineLoader::self()->supportedToLanguages(engine);
 
     if (!d->mLanguageListLoaded) {
-        fillLanguages(listLanguage);
+        fillLanguages(listFromLanguage);
         loadLanguagesList();
         d->mLanguageListLoaded = true;
     } else {
@@ -115,7 +145,11 @@ void TranslatorConfigureListsWidget::slotEngineChanged(const QString &engine)
 
         d->mFromLanguageWidget->clear();
         d->mToLanguageWidget->clear();
-        fillLanguages(listLanguage);
+        if (listFromLanguage != listToLanguage) {
+            fillFromToLanguages(listFromLanguage, listToLanguage);
+        } else {
+            fillLanguages(listFromLanguage);
+        }
 
         // Restore if possible
         d->mFromLanguageWidget->setSelectedLanguages(fromLanguages);
